@@ -19,7 +19,7 @@
 ######################################################################
 
 package Text::Wrap::OO;
-$Text::Wrap::OO::VERSION = '0.001';
+$Text::Wrap::OO::VERSION = '0.002';
 #pod =head1 SYNOPSIS
 #pod
 #pod     use Text::Wrap::OO;
@@ -78,7 +78,7 @@ $Text::Wrap::OO::VERSION = '0.001';
 #pod
 #pod =cut
 
-use v5.18;
+use v5.18.0;
 use strict;
 use warnings;
 use feature 'lexical_subs';
@@ -621,7 +621,7 @@ Text::Wrap::OO - an object oriented interface to Text::Wrap
 
 =head1 VERSION
 
-version 0.001
+version 0.002
 
 =head1 SYNOPSIS
 
